@@ -1,9 +1,5 @@
 from django_reusable import views
-
-try:
-    from django.conf.urls import url
-except ImportError:
-    from django.conf.urls.defaults import url
+from django.conf.urls import url
 
 
 urlpatterns = [
